<template>
  <div class="mobile-container">
    <!--  头部  -->
    <van-sticky>
      <van-nav-bar
        :title="`安全隐患档案`"
        left-arrow
        @click-left="_ => $router.go(-1)"
      />
    </van-sticky>
    <div class="containter-content">
      <van-form label-align="right" :readonly="true">
        <div class="hidden-trouble">
          <div
            class="trouble-content"
            v-for="(item, index) in archivesData"
            :key="index"
          >
            <div>
              <van-field
                clickable
                name="datetimePicker"
                :value="item.checkDate"
                label="隐患发现时间"
                placeholder="点击选择时间"
              />
              <van-field
                v-model="item.dangerContent"
                name="隐患内容"
                label="隐患内容"
                placeholder="请输入隐患内容"
              />
              <van-field
                v-model="item.reformSugguest"
                name="整改措施建议"
                label="整改措施建议"
                placeholder="请输入整改措施建议"
              />
              <van-field
                v-model="item.reference"
                name="参考依据说明"
                label="参考依据说明"
                placeholder="请输入参考依据说明"
              />
              <van-field name="uploader" label="隐患图片">
                <template #input>
                  <van-uploader
                    :show-upload="false"
                    :deletable="false"
                    v-model="item.imgUrlArray"
                    multiple
                  />
                </template>
              </van-field>
              <van-field name="uploader" label="整改后图片">
                <template #input>
                  <van-uploader
                    :show-upload="false"
                    :deletable="false"
                    v-model="item.reformImgUrlArray"
                    multiple
                  />
                </template>
              </van-field>
            </div>
          </div>
        </div>
      </van-form>
    </div>
  </div>
</template>

<script>
import SecurityFileApi from '@/views/Manage/saftyDanger/api/SecurityFileApi'

const {CSaftyDangerAbarbeitung} = SecurityFileApi

export default {
  name: 'MobileTrainingPlanDetail',
  data() {
    return {
      // 自定义请求参数配置对象
      customQueryPrams: {
        pageSize: -1,
        page: -1,
        't.checkDate': '',
        't.unitId': '',
        't.checkRecordId': ''
      },
      archivesData: [],
      paramsValueList: []
    }
  },
  computed: {
    routerQuery() {
      return this.$route.query
    },
    // 加工为后端需要的请求格式
    queryParams() {
      const {pageSize, page, ...item} = {
        ...this.customQueryPrams,
        ...this.routerQuery
      }
      /*
      * 定义 escapeOpt 字段对应字典名 对象，后续进行字段的翻译逻辑
      *  为重新加工结构赋值的新请求配置参数
      * */
      const querys = [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 't.checkDate',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.unitId',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.checkRecordId',
          relation: 'AND',
          value: ''
        }
      ]
      return {
        pageBean: {pageSize, page},
        querys: querys.map(i => {
          return {...i, value: item[i.property]}
        })
      }
    }
  },
  mounted() {
    this.loadData()
  },
  methods: {
    // 获取list
    async loadData() {
      const {data: {value: {rows}}} = await CSaftyDangerAbarbeitung(this.queryParams)
      let url = window.context.portal + '/file/onlinePreviewController/v1/getFileById_'
      this.archivesData = rows.map(item => {
        let imgUrlArray = item.imgUrlArray || []
        let reformImgUrlArray = item.reformImgUrlArray || []
        return {
          ...item,
          imgUrlArray: imgUrlArray.map(i => {
            return {url: url + i, isImage: true}
          }),
          reformImgUrlArray: reformImgUrlArray.map(i => {
            return {url: url + i, isImage: true}
          })
        }
      })
    }

  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables';

.mobile-container {
  width: 100%;
  min-height: 100%;
  // background-color: $--mobile-bg;
  background-color: #f4f7ff;
  overflow-y: scroll;
  box-sizing: border-box;

  .containter-sticky {
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 200;
  }

  .containter-content {
    padding: 70px 70px;
  }
}

.form-btn {
  display: flex;
  justify-content: flex-end;
}

.popup-content {
  height: 86%;
  overflow-y: scroll;
}

::v-deep .el-upload--picture-card {
  width: 350px !important;
  height: 350px !important;
  line-height: 350px !important;
}

.trouble-top {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

::v-deep .el-upload-list--picture-card .el-upload-list__item {
  width: 350px !important;
  height: 350px !important;
}

.hidden-trouble {
  .trouble-Btn {
    display: flex;
    justify-content: flex-end;
    padding: 20px 20px 0 0;
  }

  .trouble-content {
    background-color: white;
    margin-bottom: 50px;
    box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.1), 0 6px 20px 0 rgba(0, 0, 0, 0.1);
    border-radius: 20px;
    overflow: hidden;
  }

  .trouble-title {
    // font-weight: bold;
    font-size: 80px;
    margin-top: 20px;
    margin-left: 80px;
  }
}

.device-content {
  // padding: 50px 0px 50px 0px;
  height: 400px;
  font-size: 50px;

  p {
    color: #929494;
    margin: 10px 0 10px 0;
  }
}

.device-group {
  padding: 0 60px 0 60px;
  margin-top: 16px !important;
}

.group-title {
  padding: 20px 16px 10px 16px;
  color: #888888;
  font-size: 78px;
}

.title-bar {
  display: inline-block;
  width: 4px;
  height: 12px;
  background-color: #1989fa;
  margin-right: 4px;
  vertical-align: middle;
}

.device-cell {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 40px 0 40px 0;
  border-bottom: 1px solid #dedddd;
}

.device-name {
  font-size: 88px;
  color: $--mobile-text-main;
}

.cell-title {
  color: $--mobile-text-sub;
  font-size: 82px;
  margin-right: 10px;
}

.cell-value {
  color: $--mobile-text-main;
  font-size: 82px;
}

.margin-bottom {
  margin-bottom: 16px !important;
}

.device-status .van-tag {
  padding: 10px 40px 10px 40px;
  font-size: 72px;
}

.van-cell-group--inset {
  margin: 0 0;
  border-radius: 0;
}

.van-cell {
  justify-content: start;
}

.van-cell__title,
.van-cell__value {
  width: auto;
  flex: initial;
}

.van-cell__title {
  white-space: nowrap;
}

.van-cell__value {
  padding-left: 10px;
  text-align: left;
}

.van-cell__title span,
.van-cell__value span {
  font-size: 76px;
  color: $--mobile-text-main;
}

.van-cell__title span {
  color: $--mobile-text-sub;
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom';
</style>
